commit ca257739cfee104319485a5ad81c01fdc1c24124
Author: Ian Obermiller <ian@obermillers.com>
Date:   Sun Dec 16 15:17:11 2012 -0800

    Add isSelfClosing to the node passed to onopentag.

diff --git a/lib/sax.js b/lib/sax.js
index 7519cfb..560e02e 100644
--- a/lib/sax.js
+++ b/lib/sax.js
@@ -764,6 +764,8 @@ function openTag (parser, selfClosing) {
     parser.attribList.length = 0
   }
 
+  parser.tag.isSelfClosing = !!selfClosing;
+
   // process the tag
   parser.sawRoot = true
   parser.tags.push(parser.tag)
diff --git a/test/buffer-overrun.js b/test/buffer-overrun.js
index 8d12fac..57d3c41 100644
--- a/test/buffer-overrun.js
+++ b/test/buffer-overrun.js
@@ -10,7 +10,8 @@ require(__dirname).test({
     ["error", "Max buffer length exceeded: tagName\nLine: 0\nColumn: 45\nChar: "],
     ["opentag", {
      "name": "ABCDEFGHIJKLMNOPQRSTUVWXYZABCDEFGHIJKLMNOPQRSTUVWXYZ",
-     "attributes": {}
+     "attributes": {},
+     "isSelfClosing": false
     }],
     ["text", "yo"],
     ["closetag", "ABCDEFGHIJKLMNOPQRSTUVWXYZABCDEFGHIJKLMNOPQRSTUVWXYZ"]
diff --git a/test/case.js b/test/case.js
index 35ee934..9da78ab 100644
--- a/test/case.js
+++ b/test/case.js
@@ -6,7 +6,8 @@ require(__dirname).test
       [ [ "attribute", { name: "CLASS", value: "test" } ]
       , [ "attribute", { name: "HELLO", value: "world" } ]
       , [ "opentag", { name: "SPAN",
-                       attributes: { CLASS: "test", HELLO: "world" } } ]
+                       attributes: { CLASS: "test", HELLO: "world" },
+                       isSelfClosing: false } ]
       , [ "closetag", "SPAN" ]
       ]
     , strict : false
@@ -22,7 +23,8 @@ require(__dirname).test
       [ [ "attribute", { name: "class", value: "test" } ]
       , [ "attribute", { name: "hello", value: "world" } ]
       , [ "opentag", { name: "span",
-                       attributes: { class: "test", hello: "world" } } ]
+                       attributes: { class: "test", hello: "world" },
+                       isSelfClosing: false } ]
       , [ "closetag", "span" ]
       ]
     , strict : false
@@ -38,7 +40,8 @@ require(__dirname).test
       [ [ "attribute", { name: "class", value: "test" } ]
       , [ "attribute", { name: "hello", value: "world" } ]
       , [ "opentag", { name: "span",
-                       attributes: { class: "test", hello: "world" } } ]
+                       attributes: { class: "test", hello: "world" },
+                       isSelfClosing: false } ]
       , [ "closetag", "span" ]
       ]
     , strict : false
diff --git a/test/cdata-chunked.js b/test/cdata-chunked.js
index ccd5ee6..e3362bc 100644
--- a/test/cdata-chunked.js
+++ b/test/cdata-chunked.js
@@ -1,7 +1,7 @@
 
 require(__dirname).test({
   expect : [
-    ["opentag", {"name": "R","attributes": {}}],
+    ["opentag", {"name": "R","attributes": {}, "isSelfClosing": false}],
     ["opencdata", undefined],
     ["cdata", " this is character data  "],
     ["closecdata", undefined],
diff --git a/test/cdata-end-split.js b/test/cdata-end-split.js
index b41bd00..34f3450 100644
--- a/test/cdata-end-split.js
+++ b/test/cdata-end-split.js
@@ -1,7 +1,7 @@
 
 require(__dirname).test({
   expect : [
-    ["opentag", {"name": "R","attributes": {}}],
+    ["opentag", {"name": "R","attributes": {}, "isSelfClosing": false}],
     ["opencdata", undefined],
     ["cdata", " this is "],
     ["closecdata", undefined],
diff --git a/test/cdata-fake-end.js b/test/cdata-fake-end.js
index 07aeac4..ccafa1b 100644
--- a/test/cdata-fake-end.js
+++ b/test/cdata-fake-end.js
@@ -1,7 +1,7 @@
 
 var p = require(__dirname).test({
   expect : [
-    ["opentag", {"name": "R","attributes": {}}],
+    ["opentag", {"name": "R","attributes": {}, "isSelfClosing": false}],
     ["opencdata", undefined],
     ["cdata", "[[[[[[[[]]]]]]]]"],
     ["closecdata", undefined],
@@ -17,7 +17,7 @@ p.close();
 
 var p2 = require(__dirname).test({
   expect : [
-    ["opentag", {"name": "R","attributes": {}}],
+    ["opentag", {"name": "R","attributes": {}, "isSelfClosing": false}],
     ["opencdata", undefined],
     ["cdata", "[[[[[[[[]]]]]]]]"],
     ["closecdata", undefined],
diff --git a/test/cdata-multiple.js b/test/cdata-multiple.js
index dab2015..8e2f911 100644
--- a/test/cdata-multiple.js
+++ b/test/cdata-multiple.js
@@ -1,7 +1,7 @@
 
 require(__dirname).test({
   expect : [
-    ["opentag", {"name": "R","attributes": {}}],
+    ["opentag", {"name": "R","attributes": {}, "isSelfClosing": false}],
     ["opencdata", undefined],
     ["cdata", " this is "],
     ["closecdata", undefined],
diff --git a/test/cdata.js b/test/cdata.js
index 0f09cce..31a8a30 100644
--- a/test/cdata.js
+++ b/test/cdata.js
@@ -1,7 +1,7 @@
 require(__dirname).test({
   xml : "<r><![CDATA[ this is character data  ]]></r>",
   expect : [
-    ["opentag", {"name": "R","attributes": {}}],
+    ["opentag", {"name": "R","attributes": {}, "isSelfClosing": false}],
     ["opencdata", undefined],
     ["cdata", " this is character data  "],
     ["closecdata", undefined],
diff --git a/test/issue-23.js b/test/issue-23.js
index e7991b2..ccbdc35 100644
--- a/test/issue-23.js
+++ b/test/issue-23.js
@@ -13,24 +13,24 @@ require(__dirname).test
       "</compileClassesResponse>"
 
     , expect :
-      [ [ "opentag", { name: "COMPILECLASSESRESPONSE", attributes: {} } ]
-      , [ "opentag", { name : "RESULT", attributes: {} } ]
-      , [ "opentag", { name: "BODYCRC", attributes: {} } ]
+      [ [ "opentag", { name: "COMPILECLASSESRESPONSE", attributes: {}, isSelfClosing: false } ]
+      , [ "opentag", { name : "RESULT", attributes: {}, isSelfClosing: false } ]
+      , [ "opentag", { name: "BODYCRC", attributes: {}, isSelfClosing: false } ]
       , [ "text", "653724009" ]
       , [ "closetag", "BODYCRC" ]
-      , [ "opentag", { name: "COLUMN", attributes: {} } ]
+      , [ "opentag", { name: "COLUMN", attributes: {}, isSelfClosing: false } ]
       , [ "text", "-1" ]
       , [ "closetag", "COLUMN" ]
-      , [ "opentag", { name: "ID", attributes: {} } ]
+      , [ "opentag", { name: "ID", attributes: {}, isSelfClosing: false } ]
       , [ "text", "01pG0000002KoSUIA0" ]
       , [ "closetag", "ID" ]
-      , [ "opentag", {name: "LINE", attributes: {} } ]
+      , [ "opentag", {name: "LINE", attributes: {}, isSelfClosing: false } ]
       , [ "text", "-1" ]
       , [ "closetag", "LINE" ]
-      , [ "opentag", {name: "NAME", attributes: {} } ]
+      , [ "opentag", {name: "NAME", attributes: {}, isSelfClosing: false } ]
       , [ "text", "CalendarController" ]
       , [ "closetag", "NAME" ]
-      , [ "opentag", {name: "SUCCESS", attributes: {} } ]
+      , [ "opentag", {name: "SUCCESS", attributes: {}, isSelfClosing: false } ]
       , [ "text", "true" ]
       , [ "closetag", "SUCCESS" ]
       , [ "closetag", "RESULT" ]
diff --git a/test/issue-30.js b/test/issue-30.js
index c2cc809..771b14e 100644
--- a/test/issue-30.js
+++ b/test/issue-30.js
@@ -8,11 +8,11 @@ require(__dirname).test
             "</xml>"
 
     , expect :
-      [ [ "opentag", { name: "xml", attributes: {} } ]
+      [ [ "opentag", { name: "xml", attributes: {}, isSelfClosing: false } ]
       , [ "text", "\n" ]
       , [ "comment", " \n  comment with a single dash- in it\n" ]
       , [ "text", "\n" ]
-      , [ "opentag", { name: "data", attributes: {} } ]
+      , [ "opentag", { name: "data", attributes: {}, isSelfClosing: true } ]
       , [ "closetag", "data" ]
       , [ "text", "\n" ]
       , [ "closetag", "xml" ]
diff --git a/test/issue-35.js b/test/issue-35.js
index 7c521c5..64d67b3 100644
--- a/test/issue-35.js
+++ b/test/issue-35.js
@@ -4,7 +4,7 @@ require(__dirname).test
             "</xml>"
 
     , expect :
-      [ [ "opentag", { name: "xml", attributes: {} } ]
+      [ [ "opentag", { name: "xml", attributes: {}, isSelfClosing: false } ]
       , [ "text", "\r\r\n" ]
       , [ "closetag", "xml" ]
       ]
diff --git a/test/issue-47.js b/test/issue-47.js
index 911c7d0..3e18eea 100644
--- a/test/issue-47.js
+++ b/test/issue-47.js
@@ -3,7 +3,7 @@ require(__dirname).test
   ( { xml : '<a href="query.svc?x=1&y=2&z=3"/>'
     , expect : [ 
         [ "attribute", { name:'href', value:"query.svc?x=1&y=2&z=3"} ],
-        [ "opentag", { name: "a", attributes: { href:"query.svc?x=1&y=2&z=3"} } ],
+        [ "opentag", { name: "a", attributes: { href:"query.svc?x=1&y=2&z=3"}, isSelfClosing: true } ],
         [ "closetag", "a" ]
       ]
     , strict : true
diff --git a/test/issue-49.js b/test/issue-49.js
index 2964325..ff2fbf7 100644
--- a/test/issue-49.js
+++ b/test/issue-49.js
@@ -2,8 +2,8 @@
 require(__dirname).test
   ( { xml : "<xml><script>hello world</script></xml>"
     , expect :
-      [ [ "opentag", { name: "xml", attributes: {} } ]
-      , [ "opentag", { name: "script", attributes: {} } ]
+      [ [ "opentag", { name: "xml", attributes: {}, isSelfClosing: false } ]
+      , [ "opentag", { name: "script", attributes: {}, isSelfClosing: false } ]
       , [ "text", "hello world" ]
       , [ "closetag", "script" ]
       , [ "closetag", "xml" ]
@@ -16,8 +16,8 @@ require(__dirname).test
 require(__dirname).test
   ( { xml : "<xml><script><![CDATA[hello world]]></script></xml>"
     , expect :
-      [ [ "opentag", { name: "xml", attributes: {} } ]
-      , [ "opentag", { name: "script", attributes: {} } ]
+      [ [ "opentag", { name: "xml", attributes: {}, isSelfClosing: false } ]
+      , [ "opentag", { name: "script", attributes: {}, isSelfClosing: false } ]
       , [ "opencdata", undefined ]
       , [ "cdata", "hello world" ]
       , [ "closecdata", undefined ]
diff --git a/test/script.js b/test/script.js
index 464c051..fbda1f6 100644
--- a/test/script.js
+++ b/test/script.js
@@ -1,9 +1,9 @@
 require(__dirname).test({
   xml : "<html><head><script>if (1 < 0) { console.log('elo there'); }</script></head></html>",
   expect : [
-    ["opentag", {"name": "HTML","attributes": {}}],
-    ["opentag", {"name": "HEAD","attributes": {}}],
-    ["opentag", {"name": "SCRIPT","attributes": {}}],
+    ["opentag", {"name": "HTML","attributes": {}, "isSelfClosing": false}],
+    ["opentag", {"name": "HEAD","attributes": {}, "isSelfClosing": false}],
+    ["opentag", {"name": "SCRIPT","attributes": {}, "isSelfClosing": false}],
     ["script", "if (1 < 0) { console.log('elo there'); }"],
     ["closetag", "SCRIPT"],
     ["closetag", "HEAD"],
diff --git a/test/self-closing-child-strict.js b/test/self-closing-child-strict.js
index ce9c045..8c946c6 100644
--- a/test/self-closing-child-strict.js
+++ b/test/self-closing-child-strict.js
@@ -12,21 +12,25 @@ require(__dirname).test({
   expect : [
     ["opentag", {
      "name": "root",
-     "attributes": {}
+     "attributes": {},
+     "isSelfClosing": false
     }],
     ["opentag", {
      "name": "child",
-     "attributes": {}
+     "attributes": {}, 
+     "isSelfClosing": false
     }],
     ["opentag", {
      "name": "haha",
-     "attributes": {}
+     "attributes": {},
+     "isSelfClosing": true
     }],
     ["closetag", "haha"],
     ["closetag", "child"],
     ["opentag", {
      "name": "monkey",
-     "attributes": {}
+     "attributes": {},
+     "isSelfClosing": false
     }],
     ["text", "=(|)"],
     ["closetag", "monkey"],
diff --git a/test/self-closing-child.js b/test/self-closing-child.js
index bc6b52b..f31c366 100644
--- a/test/self-closing-child.js
+++ b/test/self-closing-child.js
@@ -12,21 +12,25 @@ require(__dirname).test({
   expect : [
     ["opentag", {
      "name": "ROOT",
-     "attributes": {}
+     "attributes": {},
+     "isSelfClosing": false
     }],
     ["opentag", {
      "name": "CHILD",
-     "attributes": {}
+     "attributes": {},
+     "isSelfClosing": false
     }],
     ["opentag", {
      "name": "HAHA",
-     "attributes": {}
+     "attributes": {},
+     "isSelfClosing": true
     }],
     ["closetag", "HAHA"],
     ["closetag", "CHILD"],
     ["opentag", {
      "name": "MONKEY",
-     "attributes": {}
+     "attributes": {},
+     "isSelfClosing": false
     }],
     ["text", "=(|)"],
     ["closetag", "MONKEY"],
diff --git a/test/self-closing-tag.js b/test/self-closing-tag.js
index b2c5736..d1d8b7c 100644
--- a/test/self-closing-tag.js
+++ b/test/self-closing-tag.js
@@ -9,14 +9,14 @@ require(__dirname).test({
     "</monkey>"+
   "</root>  ",
   expect : [
-    ["opentag", {name:"ROOT", attributes:{}}],
-    ["opentag", {name:"HAHA", attributes:{}}],
+    ["opentag", {name:"ROOT", attributes:{}, isSelfClosing: false}],
+    ["opentag", {name:"HAHA", attributes:{}, isSelfClosing: true}],
     ["closetag", "HAHA"],
-    ["opentag", {name:"HAHA", attributes:{}}],
+    ["opentag", {name:"HAHA", attributes:{}, isSelfClosing: true}],
     ["closetag", "HAHA"],
     // ["opentag", {name:"HAHA", attributes:{}}],
     // ["closetag", "HAHA"],
-    ["opentag", {name:"MONKEY", attributes:{}}],
+    ["opentag", {name:"MONKEY", attributes:{}, isSelfClosing: false}],
     ["text", "=(|)"],
     ["closetag", "MONKEY"],
     ["closetag", "ROOT"]
diff --git a/test/stray-ending.js b/test/stray-ending.js
index 6b0aa7f..bec467b 100644
--- a/test/stray-ending.js
+++ b/test/stray-ending.js
@@ -4,8 +4,8 @@ require(__dirname).test
   ( { xml :
       "<a><b></c></b></a>"
     , expect :
-      [ [ "opentag", { name: "A", attributes: {} } ]
-      , [ "opentag", { name: "B", attributes: {} } ]
+      [ [ "opentag", { name: "A", attributes: {}, isSelfClosing: false } ]
+      , [ "opentag", { name: "B", attributes: {}, isSelfClosing: false } ]
       , [ "text", "</c>" ]
       , [ "closetag", "B" ]
       , [ "closetag", "A" ]
diff --git a/test/trailing-non-whitespace.js b/test/trailing-non-whitespace.js
index 3e1fb2e..619578b 100644
--- a/test/trailing-non-whitespace.js
+++ b/test/trailing-non-whitespace.js
@@ -4,7 +4,8 @@ require(__dirname).test({
   expect : [
     ["opentag", {
      "name": "SPAN",
-     "attributes": {}
+     "attributes": {},
+     isSelfClosing: false
     }],
     ["text", "Welcome,"],
     ["closetag", "SPAN"],
diff --git a/test/unquoted.js b/test/unquoted.js
index dbeb638..b3a9a81 100644
--- a/test/unquoted.js
+++ b/test/unquoted.js
@@ -7,7 +7,8 @@ require(__dirname).test
       [ [ "attribute", { name: "CLASS", value: "test" } ]
       , [ "attribute", { name: "HELLO", value: "world" } ]
       , [ "opentag", { name: "SPAN",
-                       attributes: { CLASS: "test", HELLO: "world" } } ]
+                       attributes: { CLASS: "test", HELLO: "world" },
+                       isSelfClosing: false } ]
       , [ "closetag", "SPAN" ]
       ]
     , strict : false
diff --git a/test/xmlns-issue-41.js b/test/xmlns-issue-41.js
index 596d82b..17ab45a 100644
--- a/test/xmlns-issue-41.js
+++ b/test/xmlns-issue-41.js
@@ -48,6 +48,7 @@ var t = require(__dirname)
             }
           }
         , ns: {"a": "http://ATTRIBUTE"}
+        , isSelfClosing: true
         }
       ]
     , ["closetag", "parent"]
diff --git a/test/xmlns-rebinding.js b/test/xmlns-rebinding.js
index f464876..07e0425 100644
--- a/test/xmlns-rebinding.js
+++ b/test/xmlns-rebinding.js
@@ -20,20 +20,23 @@ require(__dirname).test
                         , "xmlns:y": { name: "xmlns:y", value: "y1", uri: "http://www.w3.org/2000/xmlns/", prefix: "xmlns", local: "y" }
                         , "x:a": { name: "x:a", value: "x1", uri: "x1", prefix: "x", local: "a" }
                         , "y:a": { name: "y:a", value: "y1", uri: "y1", prefix: "y", local: "a" } },
-            ns: { x: 'x1', y: 'y1' } } ]
+            ns: { x: 'x1', y: 'y1' },
+            isSelfClosing: false } ]
 
       , [ "opennamespace", { prefix: "x", uri: "x2" } ]
       , [ "attribute", { name: "xmlns:x", value: "x2", uri: "http://www.w3.org/2000/xmlns/", prefix: "xmlns", local: "x" } ]
       , [ "opentag", { name: "rebind", uri: "", prefix: "", local: "rebind",
             attributes: { "xmlns:x": { name: "xmlns:x", value: "x2", uri: "http://www.w3.org/2000/xmlns/", prefix: "xmlns", local: "x" } },
-            ns: { x: 'x2' } } ]
+            ns: { x: 'x2' },
+            isSelfClosing: false } ]
 
       , [ "attribute", { name: "x:a", value: "x2", uri: "x2", prefix: "x", local: "a" } ]
       , [ "attribute", { name: "y:a", value: "y1", uri: "y1", prefix: "y", local: "a" } ]
       , [ "opentag", { name: "check", uri: "", prefix: "", local: "check",
             attributes: { "x:a": { name: "x:a", value: "x2", uri: "x2", prefix: "x", local: "a" }
                         , "y:a": { name: "y:a", value: "y1", uri: "y1", prefix: "y", local: "a" } },
-            ns: { x: 'x2' } } ]
+            ns: { x: 'x2' },
+            isSelfClosing: true } ]
 
       , [ "closetag", "check" ]
 
@@ -45,7 +48,8 @@ require(__dirname).test
       , [ "opentag", { name: "check", uri: "", prefix: "", local: "check",
             attributes: { "x:a": { name: "x:a", value: "x1", uri: "x1", prefix: "x", local: "a" }
                         , "y:a": { name: "y:a", value: "y1", uri: "y1", prefix: "y", local: "a" } },
-            ns: { x: 'x1', y: 'y1' } } ]
+            ns: { x: 'x1', y: 'y1' },
+            isSelfClosing: true } ]
       , [ "closetag", "check" ]
 
       , [ "closetag", "root" ]
diff --git a/test/xmlns-strict.js b/test/xmlns-strict.js
index 9c7258d..b3bf530 100644
--- a/test/xmlns-strict.js
+++ b/test/xmlns-strict.js
@@ -14,12 +14,12 @@ require(__dirname).test
 
     , expect :
       [ [ "opentag", { name: "root", prefix: "", local: "root", uri: "",
-            attributes: {}, ns: {} } ]
+            attributes: {}, ns: {}, isSelfClosing: false } ]
 
       , [ "attribute", { name: "attr", value: "normal", prefix: "", local: "attr", uri: "" } ]
       , [ "opentag", { name: "plain", prefix: "", local: "plain", uri: "",
             attributes: { "attr": { name: "attr", value: "normal", uri: "", prefix: "", local: "attr", uri: "" } },
-            ns: {} } ]
+            ns: {}, isSelfClosing: true } ]
       , [ "closetag", "plain" ]
 
       , [ "opennamespace", { prefix: "", uri: "uri:default" } ]
@@ -27,11 +27,12 @@ require(__dirname).test
       , [ "attribute", { name: "xmlns", value: "uri:default", prefix: "xmlns", local: "", uri: "http://www.w3.org/2000/xmlns/" } ]
       , [ "opentag", { name: "ns1", prefix: "", local: "ns1", uri: "uri:default",
             attributes: { "xmlns": { name: "xmlns", value: "uri:default", prefix: "xmlns", local: "", uri: "http://www.w3.org/2000/xmlns/" } },
-            ns: { "": "uri:default" } } ]
+            ns: { "": "uri:default" }, isSelfClosing: false } ]
 
       , [ "attribute", { name: "attr", value: "normal", prefix: "", local: "attr", uri: "" } ]
       , [ "opentag", { name: "plain", prefix: "", local: "plain", uri: "uri:default", ns: { '': 'uri:default' },
-            attributes: { "attr": { name: "attr", value: "normal", prefix: "", local: "attr", uri: "" } } } ]
+            attributes: { "attr": { name: "attr", value: "normal", prefix: "", local: "attr", uri: "" } }, 
+            isSelfClosing: true } ]
       , [ "closetag", "plain" ]
 
       , [ "closetag", "ns1" ]
@@ -44,18 +45,20 @@ require(__dirname).test
 
       , [ "opentag", { name: "ns2", prefix: "", local: "ns2", uri: "",
             attributes: { "xmlns:a": { name: "xmlns:a", value: "uri:nsa", prefix: "xmlns", local: "a", uri: "http://www.w3.org/2000/xmlns/" } },
-            ns: { a: "uri:nsa" } } ]
+            ns: { a: "uri:nsa" }, isSelfClosing: false } ]
 
       , [ "attribute", { name: "attr", value: "normal", prefix: "", local: "attr", uri: "" } ]
       , [ "opentag", { name: "plain", prefix: "", local: "plain", uri: "",
             attributes: { "attr": { name: "attr", value: "normal", prefix: "", local: "attr", uri: "" } },
-            ns: { a: 'uri:nsa' } } ]
+            ns: { a: 'uri:nsa' },
+            isSelfClosing: true } ]
       , [ "closetag", "plain" ]
 
       , [ "attribute", { name: "a:attr", value: "namespaced", prefix: "a", local: "attr", uri: "uri:nsa" } ]
       , [ "opentag", { name: "a:ns", prefix: "a", local: "ns", uri: "uri:nsa",
             attributes: { "a:attr": { name: "a:attr", value: "namespaced", prefix: "a", local: "attr", uri: "uri:nsa" } },
-            ns: { a: 'uri:nsa' } } ]
+            ns: { a: 'uri:nsa' },
+            isSelfClosing: true } ]
       , [ "closetag", "a:ns" ]
 
       , [ "closetag", "ns2" ]
diff --git a/test/xmlns-unbound.js b/test/xmlns-unbound.js
index 2944b87..b740e26 100644
--- a/test/xmlns-unbound.js
+++ b/test/xmlns-unbound.js
@@ -8,7 +8,7 @@ require(__dirname).test(
     , [ "attribute", { name: "unbound:attr", value: "value", uri: "unbound", prefix: "unbound", local: "attr" } ]
     , [ "opentag", { name: "root", uri: "", prefix: "", local: "root",
           attributes: { "unbound:attr": { name: "unbound:attr", value: "value", uri: "unbound", prefix: "unbound", local: "attr" } },
-          ns: {} } ]
+          ns: {}, isSelfClosing: true } ]
     , [ "closetag", "root" ]
     ]
   }
diff --git a/test/xmlns-xml-default-ns.js b/test/xmlns-xml-default-ns.js
index 3eab96d..b1984d2 100644
--- a/test/xmlns-xml-default-ns.js
+++ b/test/xmlns-xml-default-ns.js
@@ -20,7 +20,8 @@ require(__dirname).test
       , [ "attribute", attr_attr ]
       , [ "opentag", { name: "elm", prefix: "", local: "elm", uri : "http://foo",
                        ns : { "" : "http://foo" },
-                       attributes: { xmlns: xmlns_attr, attr: attr_attr } } ]
+                       attributes: { xmlns: xmlns_attr, attr: attr_attr },
+                       isSelfClosing: true } ]
       , [ "closetag", "elm" ]
       , [ "closenamespace", { prefix: "", uri: "http://foo"} ]
       ]
diff --git a/test/xmlns-xml-default-prefix-attribute.js b/test/xmlns-xml-default-prefix-attribute.js
index 16da771..e41f218 100644
--- a/test/xmlns-xml-default-prefix-attribute.js
+++ b/test/xmlns-xml-default-prefix-attribute.js
@@ -24,6 +24,7 @@ require(__dirname).test(
             }
           }
         , ns: {}
+        , isSelfClosing: true
         }
       ]
     , ["closetag", "root"]
diff --git a/test/xmlns-xml-default-prefix.js b/test/xmlns-xml-default-prefix.js
index 9a1ce1b..a85b478 100644
--- a/test/xmlns-xml-default-prefix.js
+++ b/test/xmlns-xml-default-prefix.js
@@ -9,6 +9,7 @@ require(__dirname).test(
         , local: "root"
         , attributes: {}
         , ns: {}
+        , isSelfClosing: true
         }
       ]
     , ["closetag", "xml:root"]
diff --git a/test/xmlns-xml-default-redefine.js b/test/xmlns-xml-default-redefine.js
index 1eba9c7..d35d5a0 100644
--- a/test/xmlns-xml-default-redefine.js
+++ b/test/xmlns-xml-default-redefine.js
@@ -29,6 +29,7 @@ require(__dirname).test(
             }
           }
         , ns: {}
+        , isSelfClosing: true
         }
       ]
     , ["closetag", "xml:root"]
